import User from '../models/user.js';
import { uploadFile, getSignedFileUrl } from "../service/s3.service.js";

// UPDATE USER
const updateUser = async (req, res) => {
  try {
    const { name } = req.body;
    const { id } = req.user;
    const user = await User.findOne({
      where:{
        id:id
      }
    });
    if(!user) return res.status(401).json({message:"User not found"})
    await User.update({
      name
    },{
      where:{
        id:id
      }
    })
    res.status(200).json(user);
  } catch (err) {
    res.status(400).json({ error: err.message });
  }
};

// READ ALL
const getAllUsers = async (req, res) => {
  const users = await User.findAll();
  res.json(users);
};

// READ ONE
const getUserById = async (req, res) => {
  const user = await User.findByPk(req.params.id);
  if (!user) return res.status(404).json({ error: 'User not found' });
  res.json(user);
};


// DELETE
const deleteUser = async (req, res) => {
  const user = await User.findByPk(req.params.id);
  if (!user) return res.status(404).json({ error: 'User not found' });

  await user.destroy();
  res.json({ message: 'User deleted' });
};

/**
 * Upload file to S3 and return fileKey
 */
const uploadS3File = async (req, res) => {
  try {
    console.log("Received file:", req.file?.originalname);

    if (!req.file) {
      return res.status(400).json({ error: "No file provided" });
    }

    const fileKey = await uploadFile(req.file);
    res.json({ message: "File uploaded successfully", fileKey });
  } catch (err) {
    console.error("S3 upload error:", err);
    res.status(500).json({ error: err.message });
  }
};

/**
 * Generate a signed URL for S3 file
 */
const getS3SignedUrl = async (req, res) => {
  try {
    const { key } = req.params;
    if (!key) {
      return res.status(400).json({ error: "File key is required" });
    }

    const url = await getSignedFileUrl(key);
    res.json({ url });
  } catch (err) {
    console.error("S3 signed URL error:", err);
    res.status(500).json({ error: err.message });
  }
};

export default {
  updateUser,
  getAllUsers,
  getUserById,
  deleteUser,
  uploadS3File,
  getS3SignedUrl
};
