import { S3Client, PutObjectCommand, GetObjectCommand } from "@aws-sdk/client-s3";
import { getSignedUrl } from "@aws-sdk/s3-request-presigner";
import { v4 as uuidv4 } from "uuid";
import s3Client from "../utils/s3Client.js";

const bucketName = process.env.AWS_S3_BUCKET;

export const uploadFile = async (file) => {
  if (!file || !file.buffer) {
    throw new Error("Invalid file data");
  }

  const fileKey = `${uuidv4()}-${file.originalname}`;

  const command = new PutObjectCommand({
    Bucket: bucketName,
    Key: fileKey,
    Body: file.buffer,
    ContentType: file.mimetype,
  });

  await s3Client.send(command);

  return fileKey;
};

export const getSignedFileUrl = async (fileKey, expiresIn = 3600) => {
  if (!fileKey) {
    throw new Error("File key is required");
  }

  const command = new GetObjectCommand({
    Bucket: bucketName,
    Key: fileKey,
  });

  const signedUrl = await getSignedUrl(s3Client, command, { expiresIn });

  return signedUrl;
};
